/**
 * Development: Theme
 *
 * @see https://laravel-mix.com/docs/4.0/
 * @author MC|PH
 */

const mix = require('laravel-mix');

require('laravel-mix-copy-watched');
require('laravel-mix-bundle-analyzer');
require('laravel-mix-merge-manifest');

mix.inWatch = () => process.argv.includes('--watch');
mix.inBuild = () => !process.argv.includes('--watch') && !mix.inProduction();

const path = require('path');
const parentDir = path.normalize(`${__dirname}/..`);
const merge = require('webpack-merge');
const desire = require('./webpack/desire');
const dependencies = require('./webpack/dependencies');
const config = merge(desire(`${__dirname}/resources/config`), desire(`${__dirname}/resources/config-local`));
const themeResources = path.join(__dirname, 'resources');

mix
  .setPublicPath('./dist')
  .setResourceRoot(path.join(config.publicPath, mix.config.publicPath, '/'))
  .webpackConfig({
    output: { publicPath: mix.config.resourceRoot, library: 'AstraticChild' }
  });

mix.browserSync({
  proxy: config.devUrl,
  files: config.watch,
  open: config.open
})

mix.disableNotifications();

if (!mix.inProduction()) {
  mix.webpackConfig({
    devtool: 'inline-source-map',
  });
  mix.sourceMaps(false, 'inline-source-map');
}

dependencies(config.public).forEach(dependency => {
  const ext = path.parse(dependency).ext;
  const filename = path.parse(dependency).name;
  const dir = path.parse(dependency).dir;
  if ('.jsx' === ext) {
    if (mix.inProduction()) {
      mix.react(`${themeResources}/assets/${dependency}`, `${dir}/public/${filename}.js`).babel(`dist/${dir}/public/${filename}.js`, `dist/${dir}/public/${filename}.js`);
    } else {
      mix.react(`${themeResources}/assets/${dependency}`, `${dir}/public/${filename}.js`);
    }
  }
  if ('.js' === ext) {
    if (mix.inProduction()) {
      mix.js(`${themeResources}/assets/${dependency}`, `${dir}/public/${filename}.js`).babel(`dist/${dir}/public/${filename}.js`, `dist/${dir}/public/${filename}.js`);
    } else {
      mix.js(`${themeResources}/assets/${dependency}`, `${dir}/public/${filename}.js`);
    }
  }
  if ('.scss' === ext) {
    mix.sass(`${themeResources}/assets/${dependency}`, `${dir}/public/${filename}.css`).sourceMaps();
  }
})

if (mix.inBuild() || mix.inProduction()) {
  mix.copy(`${themeResources}/assets/fonts/**/*{.eot,.svg,.ttf,.woff,.woff2}`, 'dist/fonts');
  mix.copy(`${themeResources}/assets/images/**/*`, 'dist/images');
}


if (mix.inWatch()) {
  mix.copyWatched(`${themeResources}/assets/images/**/*`, 'dist/images')
}

mix.options({
  processCssUrls: false
})

if (mix.inProduction()) {
  mix.version()
}

mix.extract();

if (mix.inProduction() || mix.inBuild()) {
  mix.bundleAnalyzer({
    analyzerMode: 'static',
    openAnalyzer: false
  })
}

mix.mergeManifest();